#[repr(C)]pub struct NSFileProviderDomain { /* private fields */ }Available on crate feature
NSFileProviderDomain only.Implementations
sourceimpl NSFileProviderDomain
impl NSFileProviderDomain
pub unsafe fn initWithIdentifier_displayName_pathRelativeToDocumentStorage( this: Allocated<Self>, identifier: &NSFileProviderDomainIdentifier, display_name: &NSString, path_relative_to_document_storage: &NSString ) -> Id<Self>
pub unsafe fn initWithIdentifier_displayName( this: Allocated<Self>, identifier: &NSFileProviderDomainIdentifier, display_name: &NSString ) -> Id<Self>
pub unsafe fn identifier(&self) -> Id<NSFileProviderDomainIdentifier>
pub unsafe fn displayName(&self) -> Id<NSString>
pub unsafe fn pathRelativeToDocumentStorage(&self) -> Id<NSString>
pub unsafe fn isDisconnected(&self) -> bool
pub unsafe fn userEnabled(&self) -> bool
pub unsafe fn isHidden(&self) -> bool
pub unsafe fn setHidden(&self, hidden: bool)
pub unsafe fn isReplicated(&self) -> bool
pub unsafe fn testingModes(&self) -> NSFileProviderDomainTestingModes
pub unsafe fn setTestingModes( &self, testing_modes: NSFileProviderDomainTestingModes )
pub unsafe fn backingStoreIdentity(&self) -> Option<Id<NSData>>
pub unsafe fn supportsSyncingTrash(&self) -> bool
pub unsafe fn setSupportsSyncingTrash(&self, supports_syncing_trash: bool)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.