#[repr(C)]pub struct NSFileProviderExtension { /* private fields */ }Available on crate feature
NSFileProviderExtension only.Implementations
sourceimpl NSFileProviderExtension
impl NSFileProviderExtension
NSFileProviderActions
pub unsafe fn importDocumentAtURL_toParentItemIdentifier_completionHandler( &self, file_url: &NSURL, parent_item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn createDirectoryWithName_inParentItemIdentifier_completionHandler( &self, directory_name: &NSString, parent_item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn renameItemWithIdentifier_toName_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, item_name: &NSString, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn reparentItemWithIdentifier_toParentItemWithIdentifier_newName_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, parent_item_identifier: &NSFileProviderItemIdentifier, new_name: Option<&NSString>, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn trashItemWithIdentifier_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn untrashItemWithIdentifier_toParentItemIdentifier_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, parent_item_identifier: Option<&NSFileProviderItemIdentifier>, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn deleteItemWithIdentifier_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn setLastUsedDate_forItemIdentifier_completionHandler( &self, last_used_date: Option<&NSDate>, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn setTagData_forItemIdentifier_completionHandler( &self, tag_data: Option<&NSData>, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.pub unsafe fn setFavoriteRank_forItemIdentifier_completionHandler( &self, favorite_rank: Option<&NSNumber>, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSFileProviderItem, *mut NSError)> )
Available on crate features
NSFileProviderActions and NSFileProviderItem and block2 only.sourceimpl NSFileProviderExtension
impl NSFileProviderExtension
NSFileProviderDomain
pub unsafe fn domain(&self) -> Option<Id<NSFileProviderDomain>>
Available on crate feature
NSFileProviderDomain only.sourceimpl NSFileProviderExtension
impl NSFileProviderExtension
NSFileProviderEnumeration
pub unsafe fn enumeratorForContainerItemIdentifier_error( &self, container_item_identifier: &NSFileProviderItemIdentifier ) -> Result<Id<ProtocolObject<dyn NSFileProviderEnumerator>>, Id<NSError>>
Available on crate features
NSFileProviderEnumerating and NSFileProviderItem only.sourceimpl NSFileProviderExtension
impl NSFileProviderExtension
pub unsafe fn itemForIdentifier_error( &self, identifier: &NSFileProviderItemIdentifier ) -> Result<Id<NSFileProviderItem>, Id<NSError>>
Available on crate feature
NSFileProviderItem only.pub unsafe fn URLForItemWithPersistentIdentifier( &self, identifier: &NSFileProviderItemIdentifier ) -> Option<Id<NSURL>>
Available on crate feature
NSFileProviderItem only.pub unsafe fn persistentIdentifierForItemAtURL( &self, url: &NSURL ) -> Option<Id<NSFileProviderItemIdentifier>>
Available on crate feature
NSFileProviderItem only.pub unsafe fn providePlaceholderAtURL_completionHandler( &self, url: &NSURL, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate feature
block2 only.pub unsafe fn startProvidingItemAtURL_completionHandler( &self, url: &NSURL, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate feature
block2 only.pub unsafe fn stopProvidingItemAtURL(&self, url: &NSURL)
pub unsafe fn itemChangedAtURL(&self, url: &NSURL)
sourceimpl NSFileProviderExtension
impl NSFileProviderExtension
Methods declared on superclass NSObject
sourceimpl NSFileProviderExtension
impl NSFileProviderExtension
Deprecated
pub unsafe fn writePlaceholderAtURL_withMetadata_error( placeholder_url: &NSURL, metadata: &NSDictionary<NSURLResourceKey, AnyObject> ) -> Result<(), Id<NSError>>
👎Deprecated: Use the corresponding method on NSFileProviderManager instead
pub unsafe fn placeholderURLForURL(url: &NSURL) -> Id<NSURL>
👎Deprecated
pub unsafe fn providerIdentifier(&self) -> Id<NSString>
👎Deprecated
pub unsafe fn documentStorageURL(&self) -> Id<NSURL>
👎Deprecated
sourceimpl NSFileProviderExtension
impl NSFileProviderExtension
NSFileProviderService
pub unsafe fn supportedServiceSourcesForItemIdentifier_error( &self, item_identifier: &NSFileProviderItemIdentifier ) -> Result<Id<NSArray<ProtocolObject<dyn NSFileProviderServiceSource>>>, Id<NSError>>
Available on crate features
NSFileProviderService and NSFileProviderItem only.sourceimpl NSFileProviderExtension
impl NSFileProviderExtension
NSFileProviderThumbnailing
pub unsafe fn fetchThumbnailsForItemIdentifiers_requestedSize_perThumbnailCompletionHandler_completionHandler( &self, item_identifiers: &NSArray<NSFileProviderItemIdentifier>, size: CGSize, per_thumbnail_completion_handler: &Block<dyn Fn(NonNull<NSFileProviderItemIdentifier>, *mut NSData, *mut NSError)>, completion_handler: &Block<dyn Fn(*mut NSError)> ) -> Id<NSProgress>
Available on crate features
NSFileProviderThumbnailing and NSFileProviderItem and block2 only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.