#[repr(transparent)]
pub struct NSFileProviderItemCapabilities(pub NSUInteger);
Available on crate feature NSFileProviderItem only.

Tuple Fields

0: NSUInteger

Implementations

source

impl NSFileProviderItemCapabilities

source

pub const AllowsReading: Self = _

source

pub const AllowsWriting: Self = _

source

pub const AllowsReparenting: Self = _

source

pub const AllowsRenaming: Self = _

source

pub const AllowsTrashing: Self = _

source

pub const AllowsDeleting: Self = _

source

pub const AllowsEvicting: Self = _

👎Deprecated: use NSFileProviderContentPolicy instead
source

pub const AllowsExcludingFromSync: Self = _

source

pub const AllowsAddingSubItems: Self = _

source

pub const AllowsContentEnumerating: Self = _

source

pub const AllowsAll: Self = _

👎Deprecated: This capability is no longer supported, and does not contain all capabilities. Please migrate to directly specifying each of the individual capabilities that should be allowed for the item.