#[repr(C)]pub struct NSFileProviderManager { /* private fields */ }Available on crate feature
NSFileProviderManager only.Implementations
sourceimpl NSFileProviderManager
impl NSFileProviderManager
pub unsafe fn init(this: Allocated<Self>) -> Id<Self>
pub unsafe fn defaultManager() -> Id<NSFileProviderManager>
pub unsafe fn managerForDomain( domain: &NSFileProviderDomain ) -> Option<Id<Self>>
Available on crate feature
NSFileProviderDomain only.pub unsafe fn signalEnumeratorForContainerItemIdentifier_completionHandler( &self, container_item_identifier: &NSFileProviderItemIdentifier, completion: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderItem and block2 only.pub unsafe fn getUserVisibleURLForItemIdentifier_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSURL, *mut NSError)> )
Available on crate features
NSFileProviderItem and block2 only.pub unsafe fn getIdentifierForUserVisibleFileAtURL_completionHandler( url: &NSURL, completion_handler: &Block<dyn Fn(*mut NSFileProviderItemIdentifier, *mut NSFileProviderDomainIdentifier, *mut NSError)> )
Available on crate features
NSFileProviderDomain and NSFileProviderItem and block2 only.pub unsafe fn registerURLSessionTask_forItemWithIdentifier_completionHandler( &self, task: &NSURLSessionTask, identifier: &NSFileProviderItemIdentifier, completion: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderItem and block2 only.pub unsafe fn providerIdentifier(&self) -> Id<NSString>
pub unsafe fn documentStorageURL(&self) -> Id<NSURL>
pub unsafe fn temporaryDirectoryURLWithError( &self ) -> Result<Id<NSURL>, Id<NSError>>
pub unsafe fn writePlaceholderAtURL_withMetadata_error( placeholder_url: &NSURL, metadata: &NSFileProviderItem ) -> Result<(), Id<NSError>>
Available on crate feature
NSFileProviderItem only.pub unsafe fn placeholderURLForURL(url: &NSURL) -> Id<NSURL>
pub unsafe fn addDomain_completionHandler( domain: &NSFileProviderDomain, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderDomain and block2 only.pub unsafe fn removeDomain_completionHandler( domain: &NSFileProviderDomain, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderDomain and block2 only.pub unsafe fn removeDomain_mode_completionHandler( domain: &NSFileProviderDomain, mode: NSFileProviderDomainRemovalMode, completion_handler: &Block<dyn Fn(*mut NSURL, *mut NSError)> )
Available on crate features
NSFileProviderDomain and block2 only.pub unsafe fn getDomainsWithCompletionHandler( completion_handler: &Block<dyn Fn(NonNull<NSArray<NSFileProviderDomain>>, *mut NSError)> )
Available on crate features
NSFileProviderDomain and block2 only.pub unsafe fn removeAllDomainsWithCompletionHandler( completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate feature
block2 only.pub unsafe fn signalErrorResolved_completionHandler( &self, error: &NSError, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate feature
block2 only.pub unsafe fn globalProgressForKind( &self, kind: &NSProgressFileOperationKind ) -> Id<NSProgress>
sourceimpl NSFileProviderManager
impl NSFileProviderManager
Methods declared on superclass NSObject
sourceimpl NSFileProviderManager
impl NSFileProviderManager
MaterializedSet
pub unsafe fn enumeratorForMaterializedItems( &self ) -> Id<ProtocolObject<dyn NSFileProviderEnumerator>>
Available on crate feature
NSFileProviderEnumerating only.sourceimpl NSFileProviderManager
impl NSFileProviderManager
PendingSet
pub unsafe fn enumeratorForPendingItems( &self ) -> Id<ProtocolObject<dyn NSFileProviderPendingSetEnumerator>>
Available on crate feature
NSFileProviderEnumerating only.sourceimpl NSFileProviderManager
impl NSFileProviderManager
Import
pub unsafe fn importDomain_fromDirectoryAtURL_completionHandler( domain: &NSFileProviderDomain, url: &NSURL, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderDomain and block2 only.pub unsafe fn reimportItemsBelowItemWithIdentifier_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderItem and block2 only.pub unsafe fn requestModificationOfFields_forItemWithIdentifier_options_completionHandler( &self, fields: NSFileProviderItemFields, item_identifier: &NSFileProviderItemIdentifier, options: NSFileProviderModifyItemOptions, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderItem and NSFileProviderModifyItemOptions and block2 only.sourceimpl NSFileProviderManager
impl NSFileProviderManager
Eviction
pub unsafe fn evictItemWithIdentifier_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderItem and block2 only.sourceimpl NSFileProviderManager
impl NSFileProviderManager
Barrier
pub unsafe fn waitForChangesOnItemsBelowItemWithIdentifier_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderItem and block2 only.sourceimpl NSFileProviderManager
impl NSFileProviderManager
Stabilization
sourceimpl NSFileProviderManager
impl NSFileProviderManager
Disconnection
pub unsafe fn disconnectWithReason_options_completionHandler( &self, localized_reason: &NSString, options: NSFileProviderManagerDisconnectionOptions, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate feature
block2 only.pub unsafe fn reconnectWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate feature
block2 only.sourceimpl NSFileProviderManager
impl NSFileProviderManager
Materialize
pub unsafe fn requestDownloadForItemWithIdentifier_requestedRange_completionHandler( &self, item_identifier: &NSFileProviderItemIdentifier, range_to_materialize: NSRange, completion_handler: &Block<dyn Fn(*mut NSError)> )
Available on crate features
NSFileProviderItem and block2 only.sourceimpl NSFileProviderManager
impl NSFileProviderManager
NSFileProviderService
pub unsafe fn getServiceWithName_itemIdentifier_completionHandler( &self, service_name: &NSFileProviderServiceName, item_identifier: &NSFileProviderItemIdentifier, completion_handler: &Block<dyn Fn(*mut NSFileProviderService, *mut NSError)> )
Available on crate features
NSFileProviderService and NSFileProviderItem and block2 only.sourceimpl NSFileProviderManager
impl NSFileProviderManager
TestingModeInteractive
pub unsafe fn listAvailableTestingOperationsWithError( &self ) -> Result<Id<NSArray<ProtocolObject<dyn NSFileProviderTestingOperation>>>, Id<NSError>>
Available on crate feature
NSFileProviderTesting only.pub unsafe fn runTestingOperations_error( &self, operations: &NSArray<ProtocolObject<dyn NSFileProviderTestingOperation>> ) -> Result<Id<NSDictionary<ProtocolObject<dyn NSFileProviderTestingOperation>, NSError>>, Id<NSError>>
Available on crate feature
NSFileProviderTesting only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.