NSFileProviderCustomAction

Trait NSFileProviderCustomAction 

pub unsafe trait NSFileProviderCustomAction: NSObjectProtocol {
    // Provided method
    unsafe fn performActionWithIdentifier_onItemsWithIdentifiers_completionHandler(
        &self,
        action_identifier: &NSFileProviderExtensionActionIdentifier,
        item_identifiers: &NSArray<NSFileProviderItemIdentifier>,
        completion_handler: &DynBlock<dyn Fn(*mut NSError)>,
    ) -> Retained<NSProgress>
       where Self: Sized + Message { ... }
}
Available on crate feature NSFileProviderReplicatedExtension only.
Provided Methods

unsafe fn performActionWithIdentifier_onItemsWithIdentifiers_completionHandler( &self, action_identifier: &NSFileProviderExtensionActionIdentifier, item_identifiers: &NSArray<NSFileProviderItemIdentifier>, completion_handler: &DynBlock<dyn Fn(*mut NSError)>, ) -> Retained<NSProgress>
where Self: Sized + Message,

Available on crate features block2 and NSFileProviderActions and NSFileProviderItem only.

Perform a custom action identified by actionIdentifier, on items identified by itemIdentifiers.

Custom actions are defined in the File Provider Extension’s Info.plist, under the NSExtensionFileProviderActions key. The format of this key is identical to actions defined in a FileProviderUI extension.

Cancellations:

If the NSProgress returned by this method is cancelled, the extension should call the completion handler with (NSUserCancelledError) in the NSProgress cancellation handler.