NSFileProviderTestingCreation

Trait NSFileProviderTestingCreation 

pub unsafe trait NSFileProviderTestingCreation: NSFileProviderTestingOperation {
    // Provided methods
    unsafe fn targetSide(&self) -> NSFileProviderTestingOperationSide
       where Self: Sized + Message { ... }
    unsafe fn sourceItem(&self) -> Retained<NSFileProviderItem>
       where Self: Sized + Message { ... }
    unsafe fn domainVersion(
        &self,
    ) -> Option<Retained<NSFileProviderDomainVersion>>
       where Self: Sized + Message { ... }
}
Available on crate feature NSFileProviderTesting only.
This operation causes the system to propagate a creation of an item from a source side to a target side.

See also Apple’s documentation

Provided Methods

unsafe fn targetSide(&self) -> NSFileProviderTestingOperationSide
where Self: Sized + Message,

The target side of the operation.

unsafe fn sourceItem(&self) -> Retained<NSFileProviderItem>
where Self: Sized + Message,

Available on crate feature NSFileProviderItem only.

The description of the item.

unsafe fn domainVersion(&self) -> Option<Retained<NSFileProviderDomainVersion>>
where Self: Sized + Message,

Available on crate feature NSFileProviderDomain only.

The domain version at the time the creation was discovered on the source side.