pub unsafe trait NSFileProviderTestingModification: NSFileProviderTestingOperation {
// Provided methods
unsafe fn targetSide(&self) -> NSFileProviderTestingOperationSide
where Self: Sized + Message { ... }
unsafe fn sourceItem(&self) -> Retained<NSFileProviderItem>
where Self: Sized + Message { ... }
unsafe fn targetItemIdentifier(
&self,
) -> Retained<NSFileProviderItemIdentifier>
where Self: Sized + Message { ... }
unsafe fn targetItemBaseVersion(
&self,
) -> Retained<NSFileProviderItemVersion>
where Self: Sized + Message { ... }
unsafe fn changedFields(&self) -> NSFileProviderItemFields
where Self: Sized + Message { ... }
unsafe fn domainVersion(
&self,
) -> Option<Retained<NSFileProviderDomainVersion>>
where Self: Sized + Message { ... }
}Available on crate feature
NSFileProviderTesting only.Expand description
This operation causes the system to propagate a modification of an existing item from a source side to a target side.
The modification happens if a change is identified on an item that is already known by both sides.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn targetSide(&self) -> NSFileProviderTestingOperationSide
unsafe fn targetSide(&self) -> NSFileProviderTestingOperationSide
The target side of the operation.
Sourceunsafe fn sourceItem(&self) -> Retained<NSFileProviderItem>
Available on crate feature NSFileProviderItem only.
unsafe fn sourceItem(&self) -> Retained<NSFileProviderItem>
NSFileProviderItem only.The description of the item.
Sourceunsafe fn targetItemIdentifier(&self) -> Retained<NSFileProviderItemIdentifier>
Available on crate feature NSFileProviderItem only.
unsafe fn targetItemIdentifier(&self) -> Retained<NSFileProviderItemIdentifier>
NSFileProviderItem only.The identifier of the target item.
Sourceunsafe fn targetItemBaseVersion(&self) -> Retained<NSFileProviderItemVersion>
Available on crate feature NSFileProviderItem only.
unsafe fn targetItemBaseVersion(&self) -> Retained<NSFileProviderItemVersion>
NSFileProviderItem only.The version of the target item on top of which the modification is applied
Sourceunsafe fn changedFields(&self) -> NSFileProviderItemFields
Available on crate feature NSFileProviderItem only.
unsafe fn changedFields(&self) -> NSFileProviderItemFields
NSFileProviderItem only.The list of updated fields.
Sourceunsafe fn domainVersion(&self) -> Option<Retained<NSFileProviderDomainVersion>>
Available on crate feature NSFileProviderDomain only.
unsafe fn domainVersion(&self) -> Option<Retained<NSFileProviderDomainVersion>>
NSFileProviderDomain only.The domain version at the time the change was discovered on the source side.