#[repr(transparent)]pub struct NSFileProviderItemCapabilities(pub NSUInteger);Available on crate feature
NSFileProviderItem only.Tuple Fields
0: NSUIntegerImplementations
sourceimpl NSFileProviderItemCapabilities
impl NSFileProviderItemCapabilities
pub const AllowsReading: Self = _
pub const AllowsWriting: Self = _
pub const AllowsReparenting: Self = _
pub const AllowsRenaming: Self = _
pub const AllowsTrashing: Self = _
pub const AllowsDeleting: Self = _
pub const AllowsEvicting: Self = _
👎Deprecated: use NSFileProviderContentPolicy instead
pub const AllowsExcludingFromSync: Self = _
pub const AllowsAddingSubItems: Self = _
pub const AllowsContentEnumerating: Self = _
pub const AllowsAll: Self = _
👎Deprecated: This capability is no longer supported, and does not contain all capabilities. Please migrate to directly specifying each of the individual capabilities that should be allowed for the item.